@@ -1,5 +1,6 @@
 import logging  # noqa: INP001
 import sqlite3
+from typing import Any
 
 from .table import QolsysTable
 from .table_alarmedsensor import QolsysTableAlarmedSensor
@@ -23,6 +24,7 @@ from .table_powerg_device import QolsysTablePowerGDevice
 from .table_qolsyssettings import QolsysTableQolsysSettings
 from .table_scene import QolsysTableScene
 from .table_sensor import QolsysTableSensor
+from .table_sensor_group import QolsysTableSensorGroup
 from .table_shades import QolsysTableShades
 from .table_smartsocket import QolsysTableSmartSocket
 from .table_state import QolsysTableState
@@ -42,9 +44,7 @@ LOGGER = logging.getLogger(__name__)
 
 
 class QolsysDB:
-
     def __init__(self) -> None:  # noqa: PLR0915
-
         self._db: sqlite3.Connection = sqlite3.connect(":memory:")
         self._cursor: sqlite3.Cursor = self._db.cursor()
 
@@ -64,6 +64,7 @@ class QolsysDB:
         self.table_partition = QolsysTablePartition(self.db, self.cursor)
         self.table_powerg_device = QolsysTablePowerGDevice(self.db, self.cursor)
         self.table_sensor = QolsysTableSensor(self.db, self.cursor)
+        self.table_sensor_group = QolsysTableSensorGroup(self.db, self.cursor)
         self.table_smartsocket = QolsysTableSmartSocket(self.db, self.cursor)
         self.table_qolsyssettings = QolsysTableQolsysSettings(self.db, self.cursor)
         self.table_scene = QolsysTableScene(self.db, self.cursor)
@@ -84,8 +85,9 @@ class QolsysDB:
         self.table_shades = QolsysTableShades(self.db, self.cursor)
         self.table_nest_device = QolsysTableNestDevice(self.db, self.cursor)
 
-        self._table_array = []
+        self._table_array: list[QolsysTable] = []
         self._table_array.append(self.table_sensor)
+        self._table_array.append(self.table_sensor_group)
         self._table_array.append(self.table_partition)
         self._table_array.append(self.table_qolsyssettings)
         self._table_array.append(self.table_alarmedsensor)
@@ -153,7 +155,7 @@ class QolsysDB:
     def cursor(self) -> sqlite3.Cursor:
         return self._cursor
 
-    def get_scenes(self) -> list[dict]:
+    def get_scenes(self) -> list[dict[str, str]]:
         self.cursor.execute(f"SELECT * FROM {self.table_scene.table} ORDER BY scene_id")
         self.db.commit()
 
@@ -165,7 +167,7 @@ class QolsysDB:
 
         return scenes
 
-    def get_partitions(self) -> list[dict]:
+    def get_partitions(self) -> list[dict[str, str]]:
         self.cursor.execute(f"SELECT * FROM {self.table_partition.table} ORDER BY partition_id")
         self.db.commit()
 
@@ -177,7 +179,7 @@ class QolsysDB:
 
         return partitions
 
-    def get_zwave_devices(self) -> list[dict]:
+    def get_zwave_devices(self) -> list[dict[str, str]]:
         self.cursor.execute(f"SELECT * FROM {self.table_zwave_node.table} ORDER BY node_id")
         self.db.commit()
 
@@ -189,7 +191,7 @@ class QolsysDB:
 
         return devices
 
-    def get_locks(self) -> list[dict]:
+    def get_locks(self) -> list[dict[str, str]]:
         self.cursor.execute(f"SELECT * FROM {self.table_doorlock.table} ORDER BY node_id")
         self.db.commit()
 
@@ -201,7 +203,7 @@ class QolsysDB:
 
         return locks
 
-    def get_thermostats(self) -> list[dict]:
+    def get_thermostats(self) -> list[dict[str, str]]:
         self.cursor.execute(f"SELECT * FROM {self.table_thermostat.table} ORDER BY node_id")
         self.db.commit()
 
@@ -213,7 +215,7 @@ class QolsysDB:
 
         return thermostats
 
-    def get_dimmers(self) -> list[dict]:
+    def get_dimmers(self) -> list[dict[str, str]]:
         self.cursor.execute(f"SELECT * FROM {self.table_dimmer.table} ORDER BY node_id")
         self.db.commit()
 
@@ -225,7 +227,7 @@ class QolsysDB:
 
         return dimmers
 
-    def get_zones(self) -> list[dict]:
+    def get_zones(self) -> list[dict[str, str]]:
         self.cursor.execute(f"SELECT * FROM {self.table_sensor.table} ORDER BY zoneid")
         self.db.commit()
 
@@ -237,7 +239,7 @@ class QolsysDB:
 
         return zones
 
-    def get_weather(self) -> list[dict]:
+    def get_weather(self) -> list[dict[str, str]]:
         self.cursor.execute(f"SELECT * FROM {self.table_weather.table} ORDER BY _id")
         self.db.commit()
 
@@ -249,9 +251,9 @@ class QolsysDB:
 
         return weather_list
 
-    def get_powerg(self, short_id: str) -> dict:
+    def get_powerg(self, short_id: str) -> dict[str, str] | None:
         try:
-            self.cursor.execute(f"SELECT * FROM {self.table_powerg_device.table} WHERE shortID = ?",(short_id,))
+            self.cursor.execute(f"SELECT * FROM {self.table_powerg_device.table} WHERE shortID = ?", (short_id,))
             self.db.commit()
 
             row = self.cursor.fetchone()
@@ -261,45 +263,51 @@ class QolsysDB:
                 return None
 
             columns = [description[0] for description in self.cursor.description]
-            return  dict(zip(columns, row, strict=True))
+            return dict(zip(columns, row, strict=True))
 
         except sqlite3.Error:
             LOGGER.exception("Error getting PowerG device info for shortID %s", short_id)
             return None
 
-
     def get_setting_panel(self, setting: str) -> str:
-        self.cursor.execute(f"""SELECT value FROM {self.table_qolsyssettings.table}
-                             WHERE name = ? and partition_id  = ? """, (setting, "0"))
+        self.cursor.execute(
+            f"""SELECT value FROM {self.table_qolsyssettings.table}
+                             WHERE name = ? and partition_id  = ? """,
+            (setting, "0"),
+        )
         row = self.cursor.fetchone()
 
         if row is None:
             LOGGER.debug("%s value not found", setting)
-            return None
+            return ""
 
-        return row[0]
+        return str(row[0])
 
-    def get_setting_partition(self, setting: str, partition_id: str) -> str | None:
-        self.cursor.execute(f"""SELECT value FROM {self.table_qolsyssettings.table}
-                             WHERE name = ? and partition_id  = ? """, (setting, partition_id))
+    def get_setting_partition(self, setting: str, partition_id: str) -> str:
+        self.cursor.execute(
+            f"""SELECT value FROM {self.table_qolsyssettings.table}
+                             WHERE name = ? and partition_id  = ? """,
+            (setting, partition_id),
+        )
         row = self.cursor.fetchone()
 
         if row is None:
             LOGGER.debug("%s value not found", setting)
-            return None
+            return ""
 
-        return row[0]
+        return str(row[0])
 
     def get_state_partition(self, state: str, partition_id: str) -> str | None:
         self.cursor.execute(
-            f"""SELECT value FROM {self.table_state.table} WHERE name = ? and partition_id  = ? """, (state, partition_id))
+            f"""SELECT value FROM {self.table_state.table} WHERE name = ? and partition_id  = ? """, (state, partition_id)
+        )
         row = self.cursor.fetchone()
 
         if row is None:
             LOGGER.debug("%s value not found", state)
             return None
 
-        return row[0]
+        return str(row[0])
 
     def get_alarm_type(self, partition_id: str) -> list[str]:
         alarm_type = []
@@ -322,8 +330,7 @@ class QolsysDB:
 
         return None
 
-    def load_db(self, database: dict) -> None:
-
+    def load_db(self, database: list[dict[str, Any]]) -> None:
         self.clear_db()
 
         if not database:
@@ -331,7 +338,7 @@ class QolsysDB:
             return
 
         for uri in database:
-            table = self.get_table(uri.get("uri"))
+            table = self.get_table(uri.get("uri", ""))
 
             if table is None:
                 LOGGER.error("Please Report")
@@ -339,5 +346,5 @@ class QolsysDB:
                 LOGGER.error(uri)
                 continue
 
-            for u in uri.get("resultSet"):
+            for u in uri.get("resultSet", ""):
                 table.insert(data=u)
