@@ -7,7 +7,6 @@ LOGGER = logging.getLogger(__name__)
 
 
 class QolsysTable:
-
     def __init__(self, db: sqlite3.Connection, cursor: sqlite3.Cursor) -> None:
         self._db: sqlite3.Connection = db
         self._cursor: sqlite3.Cursor = cursor
@@ -15,7 +14,7 @@ class QolsysTable:
         self._table: str = ""
         self._columns: list[str] = []
         self._abort_on_error: bool = False
-        self._implemented:bool = False
+        self._implemented: bool = False
 
     @property
     def uri(self) -> str:
@@ -37,16 +36,18 @@ class QolsysTable:
         column_defs += [f"{col} TEXT" for col in other_columns]
 
         try:
-            query = f"CREATE TABLE {self._table} ({', '.join(column_defs)})"
+            query: str = f"CREATE TABLE {self._table} ({', '.join(column_defs)})"
             self._cursor.execute(query)
             self._db.commit()
 
         except sqlite3.Error as err:
-            error = QolsysSqlError({
-                "table": self.table,
-                "query": query,
-                "columns": self._columns,
-            })
+            error = QolsysSqlError(
+                {
+                    "table": self.table,
+                    "query": query,
+                    "columns": self._columns,
+                }
+            )
 
             if self._abort_on_error:
                 raise error from err
@@ -58,17 +59,18 @@ class QolsysTable:
             self._db.commit()
 
         except sqlite3.Error as err:
-            error = QolsysSqlError({
-                "table": self.table,
-                "query": query,
-                "columns": self._columns,
-            })
+            error = QolsysSqlError(
+                {
+                    "table": self.table,
+                    "query": query,
+                    "columns": self._columns,
+                }
+            )
 
             if self._abort_on_error:
                 raise error from err
 
-    def insert(self, data: dict) -> None:
-
+    def insert(self, data: dict[str, str]) -> None:
         try:
             if not self._implemented and data is not None:
                 LOGGER.warning("New Table format: %s", self.uri)
@@ -99,94 +101,117 @@ class QolsysTable:
             self._db.commit()
 
         except sqlite3.Error as err:
-            error = QolsysSqlError({
-                "table": self.table,
-                "query": query,
-                "columns": self._columns,
-            })
+            error = QolsysSqlError(
+                {
+                    "table": self.table,
+                    "query": query,
+                    "columns": self._columns,
+                }
+            )
 
             if self._abort_on_error:
                 raise error from err
 
-    def update(self, selection: str | None, selection_argument: list | str | None, content_value: str | None) -> None:
+    def update(
+        self, selection: str | None, selection_argument: list[str] | str | None, content_value: dict[str, str] | None
+    ) -> None:
         # selection: 'zone_id=?, parition_id=?'
         # Firmware 4.4.1: selection_argument: '[3,1]'
         # Firmware 4.6.1: selection_argument: ['3','1']
-        # contentValues:{"partition_id":"0","sensorgroup":"safetymotion","sensorstatus":"Idle"}"
 
         # Firmware 4.4.1: seletion_argument is sent as a string and needs to be converted to an array
-        if(type(selection_argument) is str):
+        if isinstance(selection_argument, str):
             selection_argument = selection_argument.strip("[]")
             selection_argument = [item.strip() for item in selection_argument.split(",")]
 
+        if selection_argument is None:
+            selection_argument = []
+
         try:
             full_data = {}
             new_columns = []
 
-            for key, value in content_value.items():
-                if key in self._columns:
-                    full_data[key] = value
-                else:
-                    new_columns.append(key)
+            # Separate valid and unknown columns
+            if content_value is not None:
+                for key, value in content_value.items():
+                    if key in self._columns:
+                        full_data[key] = value
+                    else:
+                        new_columns.append(key)
 
-            db_value = ",".join([f"{key}='{value}'" for key, value in full_data.items()])
-
-            # Warn if new column found in iq2meid database
+            # Warn for unknown columns
             if new_columns:
                 LOGGER.warning("New column found in iq2meid database")
                 LOGGER.warning("Table: %s", self.table)
                 LOGGER.warning("New Columns: %s", new_columns)
                 LOGGER.warning("Please Report")
 
-            if selection:
-                query = f"UPDATE {self.table} SET {db_value} WHERE {selection}"
-                self._cursor.execute(query, selection_argument)
-            else:
-                query = f"UPDATE {self.table} SET {db_value}"
-                self._cursor.execute(query)
+            set_clause = ", ".join([f"{key} = ?" for key in full_data])
+            set_values = list(full_data.values())
 
+            if selection:
+                query = f"UPDATE {self.table} SET {set_clause} WHERE {selection}"
+                params = set_values + selection_argument
+            else:
+                query = f"UPDATE {self.table} SET {set_clause}"
+                params = set_values
+
+            self._cursor.execute(query, params)
             self._db.commit()
 
         except sqlite3.Error as err:
-            error = QolsysSqlError({
-                "table": self.table,
-                "query": query,
-                "columns": self._columns,
-                "content_value": content_value,
-                "selection": selection,
-                "selection_argument": selection_argument,
-            })
+            error = QolsysSqlError(
+                {
+                    "table": self.table,
+                    "query": query,
+                    "columns": self._columns,
+                    "content_value": content_value,
+                    "selection": selection,
+                    "selection_argument": selection_argument,
+                }
+            )
 
             if self._abort_on_error:
                 raise error from err
 
-    def delete(self, selection: str | None, selection_argument: list | str | None) -> None:
+    def delete(self, selection: str | None, selection_argument: list[str] | str | None) -> None:
         # selection: 'zone_id=?, parition_id=?'
         # Firmware 4.4.1: selection_argument: '[3,1]'
         # Firmware 4.6.1: selection_argument: ['3','1']
 
         # Firmware 4.4.1: seletion_argument is sent as a string and needs to be converted to an array
-        if(type(selection_argument) is str):
+        if type(selection_argument) is str:
             selection_argument = selection_argument.strip("[]")
             selection_argument = [item.strip() for item in selection_argument.split(",")]
 
+        if selection_argument is None:
+            selection_argument = []
+
         try:
             if selection:
                 query = f"DELETE FROM {self.table} WHERE {selection}"
-                self._cursor.execute(query, selection_argument)
+
+                if "?" in selection:
+                    # Query expects parameters → must pass the list
+                    self._cursor.execute(query, selection_argument)
+                else:
+                    # Query has no ? , do not pass arguments
+                    self._cursor.execute(query)
             else:
                 self.clear()
 
             self._db.commit()
 
         except sqlite3.Error as err:
-            error = QolsysSqlError({
-                "table": self.table,
-                "query": query,
-                "columns": self._columns,
-                "selection": selection,
-                "selection_argument": selection_argument,
-            })
+            error = QolsysSqlError(
+                {
+                    "table": self.table,
+                    "query": query,
+                    "columns": self._columns,
+                    "selection": selection,
+                    "selection_argument": selection_argument,
+                }
+            )
 
             if self._abort_on_error:
                 raise error from err
