@@ -7,7 +7,6 @@ LOGGER = logging.getLogger(__name__)
 
 
 class QolsysTableHistory(QolsysTable):
-
     def __init__(self, db: sqlite3.Connection, cursor: sqlite3.Cursor) -> None:
         super().__init__(db, cursor)
         self._uri = "content://com.qolsys.qolsysprovider.HistoryContentProvider/history"
@@ -28,6 +27,10 @@ class QolsysTableHistory(QolsysTable):
             "feature1",
             "feature2",
             "device_id",
+            # "History Bulk Insert",
+            "Partition",
+            # "History Device Names List",
+            # "History Bypass Event",
         ]
 
         self._create_table()
